package gmodel

import (
	"context"
	"errors"
	"gorm.io/gorm"
)

type FsQrcodeSet struct {
	Id           int64   `gorm:"primary_key" json:"id"`           // id
	Name         *string `gorm:"default:''" json:"name"`          // 二维码组件名称
	Size         *int64  `gorm:"default:0" json:"size"`           // 二维码内容尺寸
	IndexX       *int64  `gorm:"default:0" json:"index_x"`        // x偏移量
	IndexY       *int64  `gorm:"default:0" json:"index_y"`        // y偏移量
	SvgWebsite   *string `gorm:"default:''" json:"svg_website"`   // website d数据
	SvgInstagram *string `gorm:"default:''" json:"svg_instagram"` // svg instagram d数据
	SvgFacebook  *string `gorm:"default:''" json:"svg_facebook"`  // svg facebook d数据
	Status       *int64  `gorm:"default:1" json:"status"`         // 状态 1正常 1删除
	AdminId      *int64  `gorm:"default:0" json:"admin_id"`       // 操作人
	Ctime        *int64  `gorm:"default:0" json:"ctime"`          // 添加时间
	Utime        *int64  `gorm:"default:0" json:"utime"`          // 更新时间
}
type FsQrcodeSetModel struct {
	db *gorm.DB
}

func NewFsQrcodeSetModel(db *gorm.DB) *FsQrcodeSetModel {
	return &FsQrcodeSetModel{db}
}
func (q *FsQrcodeSetModel) GetAll(ctx context.Context) (resp []FsQrcodeSet, err error) {
	err = q.db.WithContext(ctx).Model(&FsQrcodeSetModel{}).Where("`status` = ?", 1).Find(&resp).Error
	if err != nil {
		return nil, err
	}
	return
}
func (q *FsQrcodeSetModel) FindOne(ctx context.Context, id int64) (resp FsQrcodeSet, err error) {
	err = q.db.WithContext(ctx).Model(&FsQrcodeSetModel{}).Where("`id` = ?", id).First(&resp).Error
	if err != nil && !errors.Is(err, gorm.ErrRecordNotFound) {
		return FsQrcodeSet{}, err
	}
	return
}
