package handler

import (
	"errors"
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/utils/auth"

	"fusenapi/server/data-transfer/internal/logic"
	"fusenapi/server/data-transfer/internal/svc"
)

func GetQrCodeSetListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		// 解析jwtToken
		claims, err := svcCtx.ParseJwtToken(r)
		// 如果解析出错，则返回未授权的JSON响应并记录错误消息
		if err != nil {
			httpx.OkJsonCtx(r.Context(), w, &types.Response{
				Code:    401,
				Message: "unauthorized",
			})
			logx.Info("unauthorized:", err.Error())
			return
		}

		// 从Token里获取对应的信息
		userinfo, err := auth.GetUserInfoFormMapClaims(claims)
		// 如果获取用户信息出错，则返回未授权的JSON响应并记录错误消息
		if err != nil {
			httpx.OkJsonCtx(r.Context(), w, &types.Response{
				Code:    401,
				Message: "unauthorized",
			})
			logx.Info("unauthorized:", err.Error())
			return
		}

		l := logic.NewGetQrCodeSetListLogic(r.Context(), svcCtx)
		resp := l.GetQrCodeSetList()
		// 如果响应不为nil，则使用httpx.OkJsonCtx方法返回JSON响应;
		// 否则，发送500内部服务器错误的JSON响应并记录错误消息logx.Error。
		if resp != nil {
			httpx.OkJsonCtx(r.Context(), w, resp)
		} else {
			err := errors.New("server logic is error, resp must not be nil")
			httpx.ErrorCtx(r.Context(), w, err)
			logx.Error(err)
		}
		return
	}
}
