package handler

import (
	"errors"
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/server/home-user-auth/internal/logic"
	"fusenapi/server/home-user-auth/internal/svc"
	"fusenapi/server/home-user-auth/internal/types"
	"fusenapi/utils/auth"
)

func UserAddressListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {

		claims, err := svcCtx.ParseJwtToken(r)
		if err != nil {
			httpx.OkJsonCtx(r.Context(), w, &types.Response{
				Code:    401,
				Message: "unauthorized",
			})
			logx.Info("unauthorized:", err.Error())
		}

		userinfo, err := auth.GetUserInfoFormMapClaims(claims)
		if err != nil {
			httpx.OkJsonCtx(r.Context(), w, &types.Response{
				Code:    401,
				Message: "unauthorized",
			})
			logx.Info("unauthorized:", err.Error())
		}

		var req types.Request
		if err := httpx.Parse(r, &req); err != nil {
			httpx.OkJsonCtx(r.Context(), w, &types.Response{
				Code:    510,
				Message: "parameter error",
			})
			logx.Info(err)
			return
		}

		l := logic.NewUserAddressListLogic(r.Context(), svcCtx)
		resp := l.UserAddressList(&req, userinfo)
		if resp != nil {
			httpx.OkJsonCtx(r.Context(), w, resp)
		} else {
			err := errors.New("server logic is error, resp must not be nil")
			httpx.ErrorCtx(r.Context(), w, err)
			logx.Error(err)
		}
	}
}
